<?php

namespace Hrm\DocumentType\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\DocumentType\Models\DocumentType;

class DocumentTypePolicy
{

    /**
     * Determine if the given user can view the document_type.
     *
     * @param UserPolicy $user
     * @param DocumentType $document_type
     *
     * @return bool
     */
    public function view(UserPolicy $user, DocumentType $document_type)
    {
        if ($user->canDo('document_type.document_type.view') && $user->isAdmin()) {
            return true;
        }

        return $document_type->user_id == user_id() && $document_type->user_type == user_type();
    }

    /**
     * Determine if the given user can create a document_type.
     *
     * @param UserPolicy $user
     * @param DocumentType $document_type
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('document_type.document_type.create');
    }

    /**
     * Determine if the given user can update the given document_type.
     *
     * @param UserPolicy $user
     * @param DocumentType $document_type
     *
     * @return bool
     */
    public function update(UserPolicy $user, DocumentType $document_type)
    {
        if ($user->canDo('document_type.document_type.edit') && $user->isAdmin()) {
            return true;
        }

        return $document_type->user_id == user_id() && $document_type->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given document_type.
     *
     * @param UserPolicy $user
     * @param DocumentType $document_type
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, DocumentType $document_type)
    {
        return $document_type->user_id == user_id() && $document_type->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given document_type.
     *
     * @param UserPolicy $user
     * @param DocumentType $document_type
     *
     * @return bool
     */
    public function verify(UserPolicy $user, DocumentType $document_type)
    {
        if ($user->canDo('document_type.document_type.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given document_type.
     *
     * @param UserPolicy $user
     * @param DocumentType $document_type
     *
     * @return bool
     */
    public function approve(UserPolicy $user, DocumentType $document_type)
    {
        if ($user->canDo('document_type.document_type.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
