<?php

namespace Hrm\DocumentType\Providers;

use Illuminate\Support\ServiceProvider;

class DocumentTypeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'document_type');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'document_type');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerDocumentType();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerDocumentType()
    {
        $this->app->bind('document_type', function($app) {
            return new DocumentType($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('DocumentType', 'Lavalite\DocumentType\Facades\DocumentType');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('hrm.document_type', function ($app) {
            return $this->app->make('Hrm\DocumentType\DocumentType');
        });

                // Bind DocumentType to repository
        $this->app->bind(
            'Hrm\DocumentType\Interfaces\DocumentTypeRepositoryInterface',
            \Hrm\DocumentType\Repositories\Eloquent\DocumentTypeRepository::class
        );

        $this->app->register(\Hrm\DocumentType\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hrm\DocumentType\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and document_type's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/document_type.php', 'document_type'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeDocumentType::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hrm.document_type'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hrm/document_type.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/document_type')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/document_type')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
